ProtoIdItem

Struct ProtoIdItem 

pub struct ProtoIdItem { /* private fields */ }
Method Prototypes. Android docs

Implementations

Source

impl ProtoIdItem

pub fn shorty(&self) -> StringId

Index into the string_ids list for the short-form descriptor string of this prototype

pub fn return_type(&self) -> TypeId

Index into the type_ids list for the return type of this prototype.

pub fn params_off(&self) -> uint

Offset from the start of the file to the list of parameter types for this prototype, or 0 if this prototype has no params. The data at the location should be a list of types.