pub struct ProtoIdItem { /* private fields */ }Expand description
Method Prototypes. Android docs
Implementations
Sourceimpl ProtoIdItem
impl ProtoIdItem
Sourcepub fn shorty(&self) -> StringId
pub fn shorty(&self) -> StringId
Index into the string_ids list for the short-form descriptor string of this prototype
Sourcepub fn return_type(&self) -> TypeId
pub fn return_type(&self) -> TypeId
Index into the type_ids list for the return type of this prototype.
Sourcepub fn params_off(&self) -> uint
pub fn params_off(&self) -> uint
Offset from the start of the file to the list of parameter types for this prototype, or 0
if this prototype has no params. The data at the location should be a list of types.